import { main } from '@/api'
import request from '@/utils/require'

export function selectComplainPageList(data) {
    return request({
        url: `${main}/transaction/complain/selectComplainPageList?pageNum=${data.pageNum}&pageSize=${data.pageSize}`,
        method: 'post',
        data: data
    })
}

//删除
export function deleteComplain(data) {
    return request({
        url: `${main}/transaction/complain/deleteComplain`,
        method: 'post',
        data: data
    })
}


//场次下拉
export function selectSiteAll(data) {
    return request({
        url: `${main}/transaction/complain/selectSiteAll`,
        method: 'post',
        data: data
    })
}


//合同下拉
export function selectContracts(ccbm) {
    return request({
        url: `${main}/transaction/complain/selectContracts/${ccbm}`,
        method: 'get'
    })
}

//合同
export function selectContractDetail(id) {
    return request({
        url: `${main}/transaction/trademark/selectContractDetail/${id}`,
        method: 'post'
    })
}


//新增
export function insertComplain(data) {
    return request({
        url: `${main}/transaction/complain/insertComplain`,
        method: 'post',
        data
    })
}

//修改
export function updateComplain(data) {
    return request({
        url: `${main}/transaction/complain/updateComplain`,
        method: 'post',
        data
    })
}


//详情
export function selectComplainDetail(data) {
    return request({
        url: `${main}/transaction/complain/selectComplainDetail`,
        method: 'post',
        data
    })
}


